%****************************************************************************
%  Name     : model_radicals_states
%  Function : Solves moles of particles with 0,1,2,--- radicals as states
%  Method   : Metod that solves the equations without assuming steady state
%  Author   : Anette Hoel Helgesen 2011
%****************************************************************************/
%In the files given, the values of the parameters are not actual, and they should not be associated with the case.
function [F n_bar X N_polymer Rp Mp Np] = model_radicals_states(t,x,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi)
%% Process data from Ineos. 
index=floor(t/10)+1;
if index+1 < length(Tjin)
dt=(t-10*index)/10;
Tjin=dt*Tjin(index+1)+(1-dt)*Tjin(index);

else Tjin=Tjin(end);
end

index=floor(t/10)+1;
if index+1 < length(Tr)
dt=(t-10*index)/10;
Tr=dt*Tr(index+1)+(1-dt)*Tr(index);

else Tr=Tr(end);
end

index=floor(t/10)+1;
if index+1 < length(Xi)
dt=(t-10*index)/10;
Xi=dt*Xi(index+1)+(1-dt)*Xi(index);

else Xi=Xi(end);
end

%% Part  II. Extract present value of states
Nini=x(1);             %Initiator left in reactor [mole]
Nm=x(2);               %Monomer left in reactor [mole]
Tjout=x(3);            %Reactor jacket out temperature [K]
S=x(4);                %Surfactant [mole]
N1=x(5);               %Moles of particles with 0 radical
N2=x(6);               %Moles of particles with 1 radical
N3=x(7);               %Moles of particles with 2 radicals
N4=x(8);               %Moles of particles with 3 radicals
N5=x(9);               %Moles of particles with 4 radicals
%% Rate constants
[kp,ki,kt,ka,k_tr_mon,k_tr_CTA,k_tr_pol,kzp,kz_aq,Zp,Zaq]=rate_constant(par,Tr);

%% Part III. Intermediate calculations
Wc=((2.273*10^-13)*t^4)-((1.153*10^-8)*t^3)+((0.0001704)*t^2)-(0.6442*t)+6*10^4;  %Flow rate of water inside the jacket [g/s]
mj=1000000;    %Water in cooling jacket, given from Ineos [g] 

%Density, change with temperature in reactor (Kiparissides 1997). 
[rho_m,rho_w,rho_p]=density_process(Tr);

%Virial coefficients, from Kiparissides,w=water and m=monomer
[Bm,Bw,Bwm]=virial_coeff(Tr,par);
d_mw=2*Bwm-Bm-Bw;

%Emulgator into the reactor, find concentration of the emulgator
m_em2=par.c_em2*m_em2_tot;                                    %Total amount of only emulgator
m_em1=par.c_em1*par.m_em1_tot;                                %Total amount of only emulgator [g]
n_em1=(m_em1/par.MWemu);                                      %Mol of emulgator
Ve1=par.m_em1_tot/rho_w;                                      %Emulgator feed into reactor, model it as water (emulgator+water=water) [liter]
                  

% Heat capacity (Kiparissides (1997))
cpw=4.02*exp((1.99*10^-4)*Tr);                                %Heat capacity of water   [J/g,K]

%Mol of polymer particles, conversion and volume of reactor mixture
Mm=Nm*par.MWm;                                                %Mass of monomer left in reactor [g]
N_polymer=par.Fm_in-Nm;                                       %Polymer in reactor [mol]
m_polymer=par.m_m-Mm;
X=(1-(Nm/par.Fm_in));                                         %Conversion
[Pm_sat,Pw_sat] =saturation_pressure(Tr);

Psat=Pw_sat+Pm_sat;
%This is estimated for Mp simple method and xc found from measured data
if X >= 0 && X <= 0.005
    kde=800;
elseif X > 0.005 && X <= 1
    kde=((5.189*10^4)*X^5)-((1.513*10^5)*X^4)+((1.553*10^5)*X^3)-((6.02*10^4)*X^2)+(1352*X)+3010;
 else
    kde=0;
end


%% Monomer in particle 
[Mp,Vp]=monomer_concentration_particle(par,rho_m,rho_p,X,Psat,Xi);

%% Monomer distribution in four phases
K1=0.0088;
%[Mp,Vp,Mm,M_w,Mg,Mp_m,P]=monomer_concentration_4phase(Nm,Tr,par,Pm_sat,Pw_sat,Bm,Bw,Bwm,rho_p,rho_w,rho_m,X,K1,m_polymer,Mm,d_mw,m_w);

%% Average number of radicals per particle
r_p=(200*10^-9)/2;                                          %Radius of a particle, assumed monodisperse
Np=N1+N2+N3+N4+N5;
vp = Vp / Np / par.Na;
%% Solve a DAE system for radicals per partciel
n_bar=(0*N1+1*N2+2*N3+3*N4+4*N5)/Np;

Nrw=((2*ki*par.f_1*Nini)+(kde*Np*n_bar))/(ka*Np*par.Na); 

% Polymerization rate
Rp=kp*Mp*n_bar*Np;                 
Tave=(Tjout+Tjin)/2;              %Average temperature in cooling jacket

%Heat transfer parameters
a0=5.166542937519126e+02;
a1=-5.383589032168123e+02;
a2=4.257394824341245e+02;

U=a0+a1*Xi+a2*Xi^2;

%% Part III. Evaluate ODE set
d_Nini = -ki*Nini;
d_Nm   = -(Rp);
d_Tjout= (((Wc*cpw*(Tjin-Tjout))+(par.Ua*par.Aa*(par.Ta-Tjout))+(U*par.Ai*(Tr-Tave)))/((mj*cpw)+(par.m_met*par.cp_met)));
d_S    = Emu;

d_N0=-(ka*Nrw*N1*par.Na)+(2*(kt/(par.Na*vp))*N3)+(kde*N2); %N0
d_N1=((ka*Nrw*par.Na)*(N1-N2))+(6*(kt/(par.Na*vp))*N4)-(kde*(N2-2*N3)); %N1
d_N2=((ka*Nrw*par.Na)*(N2-N3))-(kde*(2*N3-(3*N4)))+((kt/(vp*par.Na))*(12*N5-(2*N3))); %N2
d_N3=((ka*Nrw*par.Na)*(N3-N4-N5))-((kt/(vp*par.Na))*(6*N4))-(kde*(3*N4-(4*N5))); %N3
d_N4=((ka*Nrw*par.Na)*(N4+N5))-((kt/(vp*par.Na))*(12*N5))-(kde*4*N5); %N=4


F=[d_Nini; d_Nm; d_Tjout; d_S; d_N0; d_N1; d_N2; d_N3; d_N4];


end


