%****************************************************************************
%  Name     : monomer_concentration_4phases
%  Function : Calculate monomer concentration of monomer in water, 
%             monomer rich phase, gas phase and polymer rich phase. For
%             both interval II and III. 
%  Method   : Ref: Kiparissides et al., 1997, Ind.Eng. Chem. Res. Page 1266
%             Ref: Mejdell et al., 1999, Chem.Eng Science 54. Page
%             2459-2466
%  Author   : Anette H. Helgesen 2011
%****************************************************************************/

function[Mp,Vp,Mm_m,M_w,Mg,Mp_m,P]=monomer_concentration_4phase(Nm,Tr,par,Pm_sat,Pw_sat,Bm,Bw,Bwm,rho_p,rho_w,rho_m,X,K1,m_polymer,Mm,d_mw,m_w)
  
k=50;

    delta=1/(1+exp(k*(X-par.xc)));

    P1=(Pm_sat+Pw_sat)*1;                       %[PA]    
    am = 1.0;                                   %Activity monomer 
    para_f1=Flory(Tr,am);                       %Polymer volume fraction
     
     
    ym=1-(Pw_sat/P1);
    yw=1-ym;
    B_1=Bm+((yw^2)*((2*Bwm)-Bm-Bw));           %Virial coefficient [m3/mol]
    fm_g=ym*P1*exp((B_1*P1)/(par.R*1000*Tr));  %Fugasity [Pa]
    fw_g=P1-fm_g;                              %Fugasity of water in gas phase [Pa]
    
    B_2=((ym^2)*Bm^2)+(2*ym*yw*Bwm)+((yw^2)*Bw);
    z=1+((B_2*P1)/(par.R*1000*Tr));
    Vg=(par.Vr-(par.m_m/rho_m)-(m_w/rho_w)+(par.m_m*X*((1/rho_m)-(1/rho_p))))/(1-((P1/(z*par.R*Tr))*(((ym*par.MWm)/(rho_p*1000))+(((yw*par.MWw))/(rho_w*1000))))); % Volume of gas phase [liter]
    Vg1=Vg/1000;   %[m3]
    Mg1=(par.MWm*ym*Vg1*P1)/(z*par.R*Tr);      %[g]
    Wg1=(par.MWw*yw*Vg1*P1)/(z*par.R*Tr);
    M_w1=(K1*(Pm_sat/P1))*(par.m_w-Wg1);       %[g]
    
    xs=(para_f1*rho_p)/((para_f1*rho_p)+((1-para_f1)*rho_m));
    Mm_m1=(par.m_m*((1-(X/xs))))-M_w1-Mg1;       %mass of monomer in monomer phase[g]
    Mp_m1=(par.m_m*(((X+(1e-20))/xs)))*(1-xs);   %mass of monomer in polymer rich phase [g]
    Vp1=(Mp_m1/rho_m)+((par.m_m*(X))/rho_p);     %Volume of polymer particle [l]
    Mp1=Mp_m1/(par.MWm*Vp1);                     %Concentration of monomer in polymer particle [mol/l]

if (Mm_m1 <= 0); 
    Mm_m1=0;
    
end
    para_f1 =(m_polymer*rho_p)/((m_polymer*rho_p)+(Mm*rho_m));
          
    am=florytest2(para_f1,Tr);
    fm0=Pm_sat*exp((Bm*Pm_sat)/(par.R*1000*Tr));
    
    global gx0
     options=optimset('Display','off','TolFun',1e-06); 
     if isempty(gx0)
        gx0=600000;
     end
    P2=fsolve(@pressure,gx0,options,Pw_sat,Tr,Bm,d_mw,fm0,am,par);
    gx0=P2;

    %P2=(Pm_sat+Pw_sat)*am;         

    ym=1-(Pw_sat/P2);
    yw=1-ym;
    xs=(para_f1*rho_p)/((para_f1*rho_p)+((1-para_f1)*rho_m));
    B_1=Bm+((yw^2)*((2*Bwm)-Bm-Bw)); %[m3/mol]
    fm_g=ym*P2*exp((B_1*P2)/(par.R*1000*Tr));
    fw_g=P2-fm_g;
    
    B_2=((ym^2)*Bm^2)+(2*ym*yw*Bwm)+((yw^2)*Bw);
    z=1+((B_2*P2)/(par.R*1000*Tr));
    
    Vg=(par.Vr-(par.m_m/rho_m)-(m_w/rho_w)+(par.m_m*par.xc*((1/rho_m)-(1/rho_p))))/(1-((P1/(z*par.R*Tr))*(((ym*par.MWm)/(rho_p*1000))+(((yw*par.MWw))/(rho_w*1000))))); % Volume of gas phase [liter]
    Vg1=Vg/1000;
    
    Mg2=(par.MWm*ym*Vg1*P2)/(z*par.R*Tr);        %[g]
    Wg2=(par.MWw*yw*Vg1*P2)/(z*par.R*Tr);        %[g]
    M_w2=(K1*(Pm_sat/P2))*(par.m_w-Wg2);         %[g]
    Mp_m2=(par.m_m*(1-X))-M_w2-Mg2;              %[g]
    Vp2=(Mp_m2/rho_p)+(par.m_m*(X+1e-08)/rho_p); %[l]
    Mp2=Mp_m2/(par.MWm*Vp2);                     %[mol/l]
    Mm_m2=0;

    
    Mp=((delta)*Mp1)+((1-delta)*Mp2);
    Vp=((delta)*Vp1)+((1-delta)*Vp2);
    P=((delta)*P1)+((1-delta)*P2);
    Mm_m=((delta)*Mm_m1)+((1-delta)*Mm_m2);
    M_w=((delta)*M_w1)+((1-delta)*M_w2);
    Mg=((delta)*Mg1)+((1-delta)*Mg2);
    Mp_m=((delta)*Mp_m1)+((1-delta)*Mp_m2);
    
    